@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -19,11 +19,9 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-try:
-    from django.core.urlresolvers import reverse
-except ImportError:
-    # For Django 2.0+
-    from django.urls import reverse
+
+from django.urls import reverse
+
 from rest_framework import serializers
 
 from hyperkitty.models import Attachment
