@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -19,18 +19,17 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-from django.shortcuts import get_object_or_404
 from django.core.exceptions import PermissionDenied
-from rest_framework import serializers, generics
+from django.shortcuts import get_object_or_404
+
+from rest_framework import generics, serializers
 
-from hyperkitty.models import Email, ArchivePolicy, MailingList
 from hyperkitty.lib.view_helpers import is_mlist_authorized
+from hyperkitty.models import ArchivePolicy, Email, MailingList
 from .attachment import AttachmentSerializer
 from .sender import SenderSerializer
 from .utils import (
-    MLChildHyperlinkedRelatedField,
-    IsMailingListPublicOrIsMember,
-    )
+    IsMailingListPublicOrIsMember, MLChildHyperlinkedRelatedField)
 
 
 class EmailShortSerializer(serializers.HyperlinkedModelSerializer):
