@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -19,9 +19,10 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-from rest_framework import serializers, permissions
-from hyperkitty.models import MailingList
+from rest_framework import permissions, serializers
+
 from hyperkitty.lib.view_helpers import is_mlist_authorized
+from hyperkitty.models import MailingList
 
 
 class MLChildHyperlinkedRelatedField(serializers.HyperlinkedRelatedField):
