@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
-from django.db import models, migrations
 import django.db.models.deletion
-import paintstore.fields
 import django.utils.timezone
 from django.conf import settings
+from django.db import migrations, models
+
 import pytz
+
+
 TIMEZONES = sorted([ (tz, tz) for tz in pytz.common_timezones ])
 
 
@@ -143,7 +145,7 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('name', models.CharField(unique=True, max_length=255, db_index=True)),
-                ('color', paintstore.fields.ColorPickerField(max_length=7)),
+                ('color', models.CharField(max_length=7)),
             ],
             options={
                 'verbose_name_plural': 'Thread categories',
